##  Overview
Both tags and custom fields let you bring more information to fact sheets in the inventory. They allow you to tailor your architecture model to your organization’s needs—whether through quick visual tagging or structured data capture. Both are:
  * Accessible via API and Excel (XLS/XLSX)
  * Visible in the inventory table view
  * Filterable (if configured as single-select)
  * Customizable with colors and usable as reporting views


They should always be used carefully because more data requires more effort to maintain. Ensure that the outcome exceeds the effort for each new tag or custom field added. For detailed information, refer to the documentation on [Tags](https://help.sap.com/docs/leanix/ea/tags?locale=en-US&state=PRODUCTION&version=CLOUD "Tags are labels used to classify and categorize fact sheets, making it easy to filter, organize, and analyze data. Learn how to assign and manage tags, understand when and when not to use them, as well as leverage them for filtering and reporting.") and [Adding a Custom Field](https://help.sap.com/docs/leanix/ea/fact-sheet-fields?locale=en-US&state=PRODUCTION&version=CLOUD#loio2759fb817a44101492ded5b080b9f10c__adding_a_custom_field).
The following screenshot summarizes the main properties of tags and custom fields, and where to find them in the fact sheet:
![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274507a57a4410149c85c008232d9cdf_LowRes.png)
  1. Tags are displayed prominently at the top of the fact sheet.
  2. Related fact sheets are displayed on the Relations Explorer.
  3. Custom sections and fields can be displayed at arbitrary positions defined in the meta model configuration.
  4. Different data types can be used for custom fields (for example, strings rendered as text or dates or double rendered as numbers, percentages, or costs).
